import pytest
import pysicgl


def test_init_extent():
    extent = (20, 42)
    s = pysicgl.Screen(extent)

    assert s.width == 20
    assert s.height == 42
    assert s.extent == extent


def test_init_normalization():
    from testutils import vec_add

    extent = (20, 20)
    location = (1, 1)

    expected_corners = ((0, 0), (extent[0] - 1, extent[1] - 1))
    expected_global_corners = tuple(
        vec_add(corner, location) for corner in expected_corners
    )

    s = pysicgl.Screen(extent, location)

    for (expected, corner) in zip(expected_corners, s.corners):
        assert corner == expected

    for (expected, corner) in zip(expected_global_corners, s.global_corners):
        assert corner == expected



from distutils.core import setup, Extension
from pathlib import Path, PurePath

# source files for sicgl
sicgl_root_dir = "third-party/sicgl"
sicgl_include_dirs = list(
    str(PurePath(sicgl_root_dir, include))
    for include in [
        "include",
    ]
)
sicgl_sources = list(
    str(PurePath(sicgl_root_dir, "src", source))
    for source in [
        "blit.c",
        "color_sequence.c",
        "compose.c",
        "field.c",
        "gamma.c",
        "iter.c",
        "screen.c",
        "translate.c",
        "domain/global.c",
        "domain/interface.c",
        "domain/screen.c",
        "private/direct.c",
        "private/interpolation.c",
    ]
)

pysicgl_root_dir = "."
pysicgl_include_dirs = list(
    str(PurePath(pysicgl_root_dir, include))
    for include in [
        "include",
    ]
)
pysicgl_sources = list(
    str(PurePath(pysicgl_root_dir, "src", source))
    for source in [
        "module.c",
        "color.c",
        "color_sequence.c",
        "field.c",
        "interface.c",
        "screen.c",
        "utilities.c",
        "drawing/blit.c",
        "drawing/compose.c",
        "drawing/field.c",
        "drawing/interface.c",
        "drawing/screen.c",
        "drawing/global.c",
    ]
)

pysicgl = Extension(
    "pysicgl",
    include_dirs=[*pysicgl_include_dirs, *sicgl_include_dirs],
    sources=[*pysicgl_sources, *sicgl_sources],
)

setup(
    ext_modules=[pysicgl],
    setup_requires=["setuptools_scm"],
)
